@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ob-gleam" "0.1.1"
+(define-package "ob-gleam" "20260221.2046"
   "Org Babel functions for Gleam."
   '((emacs "29.1"))
   :url "https://github.com/takeokunn/ob-gleam"
-  :commit "22fae3e741647750a603fdac29eb61b5c052f3da"
-  :revdesc "22fae3e74164"
+  :commit "31a521c165426954e565ea368da81c4500885f30"
+  :revdesc "31a521c16542"
   :keywords '("languages" "tools")
   :authors '(("takeokunn" . "bararararatty@gmail.com"))
   :maintainers '(("takeokunn" . "bararararatty@gmail.com")))
